'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/*
* Util methods
*/
var Util = function () {
  function Util() {
    _classCallCheck(this, Util);
  }

  _createClass(Util, null, [{
    key: 'deepObfuscateValue',


    /*
    * Recursive class to obfuscate attribute in a payload
    *
    * @params [Object] payload to obfuscate
    * @params [Array] field names to obfuscate
    *
    * @return [Object]
    */
    value: function deepObfuscateValue(payload, fields) {
      var _this = this;

      if (this.isArray(payload)) {
        return payload.map(function (e) {
          return _this.deepObfuscateValue(e, fields);
        });
      } else if (this.isObject(payload)) {
        var copy = {};

        Object.keys(payload).forEach(function (key) {
          copy[key] = fields.includes(key) ? '[HIDDEN]' : _this.deepObfuscateValue(payload[key], fields);
        });

        return copy;
      }

      return payload;
    }

    /*
    * Underscore a string
    *
    * @params [String] string to transform
    *
    * @return [String] transformed
    */

  }, {
    key: 'underscore',
    value: function underscore(str) {
      return str.replace(/([a-z\d])([A-Z]+)/g, '$1_$2').replace(/[-\s]+/g, '_').toLowerCase();
    }

    /*
    * Recursive class to underscore attributes in a payload
    *
    * @params [Object] payload to transform
    * @params [func] called for every object value
    *
    * @return [Object] transformed
    */

  }, {
    key: 'deepUnderscore',
    value: function deepUnderscore(payload) {
      var _this2 = this;

      var objectReplacer = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

      var copy = {};

      Object.keys(payload).forEach(function (key) {
        var value = payload[key];

        if (_this2.isArray(value)) {
          copy[_this2.underscore(key)] = value.map(function (v) {
            return _this2.isObject(v) ? _this2.deepUnderscore(v, objectReplacer) : v;
          });
        } else if (_this2.isObject(value)) {
          var newValue = !objectReplacer ? value : objectReplacer(value);

          copy[_this2.underscore(key)] = _this2.isObject(newValue) ? _this2.deepUnderscore(newValue, objectReplacer) : newValue;
        } else {
          copy[_this2.underscore(key)] = value;
        }
      });

      return copy;
    }

    /*
    * Remove null, undefined value from an object
    *
    * @params [Object] payload to transform
    *
    * @return [Object] transformed
    */

  }, {
    key: 'compact',
    value: function compact(object) {
      var _this3 = this;

      var clone = void 0;

      if (this.isArray(object)) {
        clone = [];

        object.forEach(function (value) {
          if (!_this3.isEmpty(value)) clone.push(value);
        });
      } else {
        clone = this.clone(object);

        Object.keys(object).forEach(function (key) {
          if (_this3.isEmpty(object[key])) delete clone[key];
        });
      }

      return clone;
    }

    /*
    * Remove null, undefined value from an object
    *
    * @params [Object] payload to transform
    *
    * @return [Object] transformed
    */

  }, {
    key: 'deepCompact',
    value: function deepCompact(object) {
      var _this4 = this;

      var clone = this.clone(object);

      Object.keys(clone).forEach(function (key) {
        var value = clone[key];

        if (_this4.isArray(value)) {
          clone[key] = _this4.compact(value.map(function (v) {
            if (_this4.isEmpty(v)) return null;
            if (_this4.isObject(v)) return _this4.deepCompact(v);
            return v;
          }));
        } else if (_this4.isObject(value)) {
          clone[key] = _this4.deepCompact(value);
        } else if (_this4.isEmpty(value)) {
          delete clone[key];
        }
      });

      return clone;
    }

    /*
    * Check if an object is a object
    *
    * @params [Any Object] to verify
    *
    * @return [Boolean]
    */

  }, {
    key: 'isObject',
    value: function isObject(obj) {
      var type = typeof obj === 'undefined' ? 'undefined' : _typeof(obj);

      return (type === 'function' || type === 'object') && !!obj;
    }

    /*
    * Check if an object is an array
    *
    * @params [Any Object] to verify
    *
    * @return [Boolean]
    */

  }, {
    key: 'isArray',
    value: function isArray(obj) {
      return toString.call(obj) === '[object Array]';
    }

    /*
    * Check if an object is a string
    *
    * @params [Any Object] to verify
    *
    * @return [Boolean]
    */

  }, {
    key: 'isString',
    value: function isString(obj) {
      return toString.call(obj) === '[object String]';
    }

    /*
    * Check if an object is a boolean
    *
    * @params [Any Object] to verify
    *
    * @return [Boolean]
    */

  }, {
    key: 'isBoolean',
    value: function isBoolean(obj) {
      return toString.call(obj) === '[object Boolean]';
    }

    /*
    * Check if an object is a number
    *
    * @params [Any Object] to verify
    *
    * @return [Boolean]
    */

  }, {
    key: 'isNumber',
    value: function isNumber(obj) {
      return toString.call(obj) === '[object Number]';
    }

    /*
    * Check if an object is empty
    *
    * @params [Any Object] to verify
    *
    * @return [Boolean]
    */

  }, {
    key: 'isEmpty',
    value: function isEmpty(obj) {
      if (obj === null || obj === undefined) return true;
      if (this.isBoolean(obj)) return false;
      if (this.isNumber(obj)) return false;
      if (this.isArray(obj) || this.isString(obj)) return obj.length === 0;
      return Object.keys(obj).length === 0;
    }

    /*
    * Clone an object
    *
    * @params [Object] to clone
    *
    * @return [Object]
    */

  }, {
    key: 'clone',
    value: function clone(obj) {
      return Object.assign({}, obj);
    }

    /*
    * lookup path in a nested object
    *
    * @param [Object]
    * @param [Args] path to lookup
    *
    * @return [Object] value of the path
    */

  }, {
    key: 'lookup',
    value: function lookup(object) {
      var obj = object;

      for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      for (var i = 0; i < args.length; i++) {
        try {
          if (!obj || !(args[i] in obj)) {
            return undefined;
          }
        } catch (e) {
          return undefined;
        }

        obj = obj[args[i]];
      }

      return obj;
    }

    /*
    * Transform object into url string params
    *
    * @param [Object] List of params
    *
    * @return [String] params for url
    */

  }, {
    key: 'toUrlParams',
    value: function toUrlParams(object) {
      return Object.keys(object).map(function (key) {
        return encodeURIComponent(key) + '=' + encodeURIComponent(object[key]);
      }).join('&');
    }
  }]);

  return Util;
}();

exports.default = Util;