import {
  expect,
  fetchMock,
  sourcesPath,
  mockConfigurations,
} from './support/setup.js';

const ApiRequest = require(`${sourcesPath}/api_request`).default;

describe('ApiRequest', () => {

  beforeEach(() => {
    mockConfigurations();
  });

  afterEach(() => {
    fetchMock.reset()
    fetchMock.restore()
  });

  describe('.get', () => {
    it('send the correct method and request', () => {
      fetchMock.getOnce(new RegExp(/\/events\?id=42\&sent_at=*/), { body: [{ id: 42 }], headers: {} });

      ApiRequest.get({ id: 42 }, { url: '/events' }).then((response) => {
        expect(response.status).to.eq(200);
        return response.json()
      }).then((response) => {
        expect(response).to.have.deep.members([{ id: 42 }]);
      });
    });
  });

  describe('.post', () => {
    it('send the correct method and request', () => {
      fetchMock.postOnce('/events', { body: [{ name: 'test' }], headers: {} });

      ApiRequest.post({ id: 42 }, { url: '/events' }).then((response) => {
        expect(response.status).to.eq(200);
        return response.json()
      }).then((response) => {
        expect(response).to.have.deep.members([{ name: 'test' }]);
      });
    });
  });

  describe('.put', () => {
    it('send the correct method and request', () => {
      fetchMock.putOnce('/events/42', { body: [{ name: 'test' }], headers: {} });

      ApiRequest.put({ name: 'test' }, { url: '/events/42' }).then((response) => {
        expect(response.status).to.eq(200);
        return response.json()
      }).then((response) => {
        expect(response).to.have.deep.members([{ name: 'test' }]);
      });
    });
  });

  describe('.patch', () => {
    it('send the correct method and request', () => {
      fetchMock.patchOnce('/events/42', { body: [{ name: 'test' }], headers: {} });

      ApiRequest.patch({ name: 'test' }, { url: '/events/42' }).then((response) => {
        expect(response.status).to.eq(200);
        return response.json()
      }).then((response) => {
        expect(response).to.have.deep.members([{ name: 'test' }]);
      });
    });
  });

  describe('.delete', () => {
    it('send the correct method and request', () => {
      fetchMock.deleteOnce('/events/42', { body: [{ name: 'test' }], headers: {} });

      ApiRequest.delete({ name: 'test' }, { url: '/events/42' }).then((response) => {
        expect(response.status).to.eq(200);
        return response.json()
      }).then((response) => {
        expect(response).to.have.deep.members([{ name: 'test' }]);
      });
    });
  });

  describe('.request', () => {
    it('send the correct method and request', () => {
      fetchMock.getOnce(new RegExp(/\/another\?id=42\&sent_at=*/), { body: [{ name: 'test' }], headers: {} });

      ApiRequest.request('GET', '/another', { id: 42 }).then((response) => {
        expect(response.status).to.eq(200);
        return response.json()
      }).then((response) => {
        expect(response).to.have.deep.members([{ name: 'test' }]);
      });
    });
  });

});
