import {
  expect,
  sourcesPath,
} from './support/setup.js';

const Config = require(`${sourcesPath}/config`).default;

describe('Config', () => {

  describe('.initialize', () => {
    it('with default data', () => {
      const expectedConfig = {
        version: '1.5.0',
        libraryName: 'liveqa',
        language: 'javascript',
        host: 'https://api.liveqa.io',
        apiVersion: 'v1',
        trackerCookieName: 'liveqa_tracker_id',
        enabled: true,
        obfuscatedFields: [],
        metadata: {},
      };

      Config.initialize();

      expect(Config.configurations).to.deep.eq(expectedConfig);
    });

    it('with custom data', () => {
      const expectedConfig = {
        version: '1.5.0',
        libraryName: 'liveqa',
        language: 'javascript',
        host: 'https://api.liveqa.io',
        apiVersion: 'v1',
        trackerCookieName: 'liveqa_tracker_id',
        enabled: false,
        obfuscatedFields: [],
        metadata: {},
        accountToken: 'acc_42'
      };

      Config.initialize({
        accountToken: 'acc_42' ,
        enabled: false
      });

      expect(Config.configurations).to.deep.eq(expectedConfig);
    });
  });

  describe('.reset', () => {

    it('with custom data', () => {
      const expectedConfig = {
        version: '1.5.0',
        libraryName: 'liveqa',
        language: 'javascript',
        host: 'https://api.liveqa.io',
        apiVersion: 'v1',
        trackerCookieName: 'liveqa_tracker_id',
        enabled: true,
        obfuscatedFields: [],
        metadata: {},
      };

      Config.initialize({
        accountToken: 'acc_42' ,
        enabled: false
      });

      Config.reset();

      expect(Config.configurations).to.deep.eq(expectedConfig);
    });
  });

});
