import {
  expect,
  createSandbox,
  sourcesPath,
  mockConfigurations,
  Config,
} from './support/setup.js';

const Event = require(`${sourcesPath}/event`).default;
const Group = require(`${sourcesPath}/group`).default;
const Identity = require(`${sourcesPath}/identity`).default;
const Watcher = require(`${sourcesPath}/watcher`).default;

const LiveQA = require(`${sourcesPath}/index`);

describe('LiveQA', () => {
  let sandbox;

  beforeEach(() => {
    sandbox = createSandbox();
    mockConfigurations();
  });

  afterEach(() => {
    sandbox.restore();
  })

  describe('#track', () => {
    it('call Event', () => {
      let spy = sandbox.stub(Event, 'create');

      LiveQA.track('Pay button', { userId: 42, properties: { title: 'Intro to Analytics' }});

      expect(spy).to.have.been.calledOnce;
    })

    it('does not call Liveqa is not enabled', () => {
      Config.enabled = false;

      let spy = sandbox.stub(Event, 'create');

      LiveQA.track('Pay button', { userid: 42, properties: { title: 'Intro to Analytics' }});

      expect(spy).to.have.not.been.called;
    })
  })

  describe('#identify', () => {
    it('call Event', () => {
      let spy = sandbox.stub(Event, 'create');

      LiveQA.identify(42, { tracker_id: 'xx', properties: { title: 'Intro to Analytics' }});

      expect(spy).to.have.been.calledOnce;
    })

    it('does not call Liveqa is not enabled', () => {
      Config.enabled = false;

      let spy = sandbox.stub(Event, 'create');

      LiveQA.identify(42, { tracker_id: 'xx', properties: { title: 'Intro to Analytics' }});

      expect(spy).to.have.not.been.called;
    })
  })

  describe('#setGroup', () => {
    it('call Group', () => {
      let spy = sandbox.stub(Group, 'update');

      LiveQA.setGroup(42);

      expect(spy).to.have.been.calledOnce;
    })

    it('does not call Liveqa is not enabled', () => {
      Config.enabled = false;

      let spy = sandbox.stub(Group, 'update');

      LiveQA.setGroup(42);

      expect(spy).to.have.not.been.called;
    })
  })

  describe('#setIdentity', () => {
    it('call Identity', () => {
      let spy = sandbox.stub(Identity, 'update');

      LiveQA.setIdentity(42);

      expect(spy).to.have.been.calledOnce;
    })

    it('does not call Liveqa is not enabled', () => {
      Config.enabled = false;

      let spy = sandbox.stub(Identity, 'update');

      LiveQA.setIdentity(42);

      expect(spy).to.have.not.been.called;
    })
  })

  describe('#watch', () => {
    it('call Watcher', () => {
      let spy = sandbox.stub(Watcher, 'create');

      LiveQA.watch(42);

      expect(spy).to.have.been.calledOnce;
    })

    it('does not call Liveqa is not enabled', () => {
      Config.enabled = false;

      let spy = sandbox.stub(Watcher, 'create');

      LiveQA.watch(42);

      expect(spy).to.have.not.been.called;
    })
  })

})
