import {
  expect,
  sourcesPath,
} from './support/setup.js';

const Util = require(`${sourcesPath}/util`).default;

describe('Util', () => {

  describe('.deepObfuscateValue', () => {

    it('obfuscate', () => {
      const fields = ['password', 'credit_card'];
      const payload = {
        password: 'test',
        another_key: {
          credit_card: '41111111',
          valid_key: 'test'
        },
        withArray: [
          {
            credit_card: '41111111',
            valid_key: 'test'
          }
        ]
      };
      const expected = {
        password: '[HIDDEN]',
        another_key: {
          credit_card: '[HIDDEN]',
          valid_key: 'test'
        },
        withArray: [
          {
            credit_card: '[HIDDEN]',
            valid_key: 'test'
          }
        ]
      };

      expect(Util.deepObfuscateValue(payload, fields)).to.deep.equal(expected);
    })

  });

  describe('.underscore', () => {

    it('underscore string', () => {
      expect(Util.underscore('userId')).to.eq('user_id');
    })

  });

  describe('.deepUnderscore', () => {

    it('deep', () => {
      const payload = {
        userId: 'test',
        another_key: {
          trackerId: '41111111',
          other: [{
            eventId: 'test'
          }]
        }
      };
      const expected = {
        user_id: 'test',
        another_key: {
          tracker_id: '41111111',
          other: [{
            event_id: 'test'
          }]
        }
      };

      expect(Util.deepUnderscore(payload)).to.deep.equal(expected);
    })

  });

  describe('.compact', () => {

    it('deep', () => {
      const payload = {
        user_id: 'test',
        another_key: undefined,
        host: null,
      };
      const expected = {
        user_id: 'test',
      };

      expect(Util.compact(payload)).to.deep.equal(expected);
    })

    it('deep', () => {
      const payload = [1, null, undefined];
      const expected = [1];

      expect(Util.compact(payload)).to.deep.equal(expected);
    })

  });

  describe('.deepCompact', () => {
    it('deep', () => {
      const payload = {
        user_id: 'test',
        another_key: undefined,
        host: null,
        nested: {
          user_id: 'test',
          another_key: undefined,
          host: null,
        },
        withArray: [
          {},
          {
            test: true
          }
        ]
      };
      const expected = {
        user_id: 'test',
        nested: {
          user_id: 'test',
        },
        withArray: [
          {
            test: true
          }
        ]
      };

      expect(Util.deepCompact(payload)).to.deep.equal(expected);
    })
  });

  describe('.isEmpty', () => {
    it('with array', () => {
      expect(Util.isEmpty([])).to.eq(true);
      expect(Util.isEmpty([1])).to.eq(false);
    })

    it('with object', () => {
      expect(Util.isEmpty({})).to.eq(true);
      expect(Util.isEmpty({ test: true })).to.eq(false);
    })

    it('with string', () => {
      expect(Util.isEmpty('')).to.eq(true);
      expect(Util.isEmpty('test')).to.eq(false);
    })

    it('with boolean', () => {
      expect(Util.isEmpty(true)).to.eq(false);
      expect(Util.isEmpty(false)).to.eq(false);
    })

    it('other', () => {
      expect(Util.isEmpty(null)).to.eq(true);
      expect(Util.isEmpty(undefined)).to.eq(true);
    })

  });

  describe('.lookup', () => {

    it('deep', () => {
      const payload = {
        level1: {
          level2: {
            level3: 'test'
          }
        }
      };

      expect(Util.lookup(payload, 'level1', 'level2', 'level3')).to.eq('test');
      expect(Util.lookup(payload, 'level1', 'level2')).to.deep.eq({ level3: 'test'});
      expect(Util.lookup(payload, 'level1', 'level2', 'wrong')).to.deep.eq(undefined);
    })

  });

})
